import {jest} from '@jest/globals';

import BusStopInfoService from './BusStopInfoService';

const service = new BusStopInfoService([
  {
    lineNumber: '803010',
    description: 'Tucapel',
    locomotionType: 1,
    backgroundColor: 'Hexadecimal',
    letterColor: 'Hexadecimal',
    lineMessage: '',
    arrivals: [
      {
        carPlate: 'RPDA-98',
        planned: '',
        estimatedGPS: '15:08',
        distanceGPS: '1.0 KM',
      },
      {
        carPlate: 'WYXYZ-22',
        planned: '',
        estimatedGPS: '15:42',
        distanceGPS: '5.0 KM',
      },
      {
        carPlate: 'ABCA-65',
        planned: '',
        estimatedGPS: '17:18',
        distanceGPS: '13.4 KM',
      },
    ],
  },
  {
    lineNumber: '5487',
    description: 'Centauro',
    locomotionType: 1,
    backgroundColor: 'Hexadecimal',
    letterColor: 'Hexadecimal',
    lineMessage: 'Sin info. GPS, la informacion es estimada',
    arrivals: [
      {
        carPlate: 'PLKJ-32',
        planned: '15:13',
        estimatedGPS: '15:13',
        distanceGPS: '',
      },
      {
        carPlate: 'GHLK-11',
        planned: '15:39',
        estimatedGPS: '15:39',
        distanceGPS: '',
      },
      {
        carPlate: 'DFQW-55',
        planned: '17:22',
        estimatedGPS: '17:22',
        distanceGPS: '',
      },
    ],
  },
]);

jest.useFakeTimers({legacyFakeTimers: false});

describe('BusStopInfoService tests', () => {
  it('should be defined', () => {
    expect(BusStopInfoService).toBeTruthy();
  });

  describe('getBuses', () => {
    it('should return a list of buses', () => {
      const buses = service.getLines();

      expect(buses).toHaveLength(2);
      expect(buses).toMatchObject([
        {
          lineNumber: '803010',
          description: 'Tucapel',
          locomotionType: 1,
          backgroundColor: 'Hexadecimal',
          letterColor: 'Hexadecimal',
          lineMessage: '',
          arrivals: [
            {
              carPlate: 'RPDA-98',
              planned: '',
              estimatedGPS: '15:08',
              distanceGPS: '1.0 KM',
            },
            {
              carPlate: 'WYXYZ-22',
              planned: '',
              estimatedGPS: '15:42',
              distanceGPS: '5.0 KM',
            },
            {
              carPlate: 'ABCA-65',
              planned: '',
              estimatedGPS: '17:18',
              distanceGPS: '13.4 KM',
            },
          ],
        },
        {
          lineNumber: '5487',
          description: 'Centauro',
          locomotionType: 1,
          backgroundColor: 'Hexadecimal',
          letterColor: 'Hexadecimal',
          lineMessage: 'Sin info. GPS, la informacion es estimada',
          arrivals: [
            {
              carPlate: 'PLKJ-32',
              planned: '15:13',
              estimatedGPS: '15:13',
              distanceGPS: '',
            },
            {
              carPlate: 'GHLK-11',
              planned: '15:39',
              estimatedGPS: '15:39',
              distanceGPS: '',
            },
            {
              carPlate: 'DFQW-55',
              planned: '17:22',
              estimatedGPS: '17:22',
              distanceGPS: '',
            },
          ],
        },
      ]);
    });
  });

  it('should return a bus by lineNumber', () => {
    const bus = service.getLinesByNumber('803010');

    expect(bus).toMatchObject({
      lineNumber: '803010',
      description: 'Tucapel',
      locomotionType: 1,
      backgroundColor: 'Hexadecimal',
      letterColor: 'Hexadecimal',
      lineMessage: '',
      arrivals: [
        {
          carPlate: 'RPDA-98',
          planned: '',
          estimatedGPS: '15:08',
          distanceGPS: '1.0 KM',
        },
        {
          carPlate: 'WYXYZ-22',
          planned: '',
          estimatedGPS: '15:42',
          distanceGPS: '5.0 KM',
        },
        {
          carPlate: 'ABCA-65',
          planned: '',
          estimatedGPS: '17:18',
          distanceGPS: '13.4 KM',
        },
      ],
    });
  });

  describe('pruneBusList', () => {
    it('should return a list of buses', () => {
      const prunedList = service.pruneBusList(0, 3);

      expect(prunedList).toHaveLength(2);
      expect(prunedList).toMatchObject([
        {
          lineNumber: '803010',
          description: 'Tucapel',
          locomotionType: 1,
          backgroundColor: 'Hexadecimal',
          letterColor: 'Hexadecimal',
          lineMessage: '',
          arrivals: [
            {
              carPlate: 'RPDA-98',
              planned: '',
              estimatedGPS: '15:08',
              distanceGPS: '1.0 KM',
            },
            {
              carPlate: 'WYXYZ-22',
              planned: '',
              estimatedGPS: '15:42',
              distanceGPS: '5.0 KM',
            },
            {
              carPlate: 'ABCA-65',
              planned: '',
              estimatedGPS: '17:18',
              distanceGPS: '13.4 KM',
            },
          ],
        },
        {
          lineNumber: '5487',
          description: 'Centauro',
          locomotionType: 1,
          backgroundColor: 'Hexadecimal',
          letterColor: 'Hexadecimal',
          lineMessage: 'Sin info. GPS, la informacion es estimada',
          arrivals: [
            {
              carPlate: 'PLKJ-32',
              planned: '15:13',
              estimatedGPS: '15:13',
              distanceGPS: '',
            },
            {
              carPlate: 'GHLK-11',
              planned: '15:39',
              estimatedGPS: '15:39',
              distanceGPS: '',
            },
            {
              carPlate: 'DFQW-55',
              planned: '17:22',
              estimatedGPS: '17:22',
              distanceGPS: '',
            },
          ],
        },
      ]);
    });
  });

  describe('getNextArraival', () => {
    beforeEach(() => {
      jest.useFakeTimers({legacyFakeTimers: false});
    });

    afterEach(() => {
      jest.useRealTimers();
    });

    it('should return next arraival', () => {
      jest.setSystemTime(new Date('2024-11-25T16:33:37').getTime());

      const nextArraival = service.getNextArraival('803010');

      expect(nextArraival).toMatchObject({
        carPlate: 'ABCA-65',
        planned: '',
        estimatedGPS: '17:18',
        distanceGPS: '13.4 KM',
      });
    });

    it('should throw an error if not arraival found', () => {
      jest.setSystemTime(new Date('2024-11-25T20:33:37').getTime());

      expect(() => {
        service.getNextArraival('803010');
      }).toThrow('No next arrival');
    });
  });

  describe('isArraivalTimeBetween tests', () => {
    beforeEach(() => {
      jest.useFakeTimers({legacyFakeTimers: false});
    });

    afterEach(() => {
      jest.useRealTimers();
    });

    it('should return < a 3 minutos', () => {
      jest.setSystemTime(new Date('2024-11-25T17:17:37').getTime());
      const arraival = {
        carPlate: 'ABCA-65',
        planned: '',
        estimatedGPS: '17:18',
        distanceGPS: '13.4 KM',
      };

      const arraivalTimeText = service.checkArraivalTime(arraival);

      expect(arraivalTimeText).toStrictEqual('< a 3 minutos');
    });

    it('should return Entre 3 a 5 minutos', () => {
      jest.setSystemTime(new Date('2024-11-25T17:14:59').getTime());
      const arraival = {
        carPlate: 'ABCA-65',
        planned: '',
        estimatedGPS: '17:18',
        distanceGPS: '13.4 KM',
      };

      const arraivalTimeText = service.checkArraivalTime(arraival);

      expect(arraivalTimeText).toStrictEqual('Entre 3 a 5 minutos');
    });

    it('should return Menos de 10 minutos', () => {
      jest.setSystemTime(new Date('2024-11-25T17:09:37').getTime());
      const arraival = {
        carPlate: 'ABCA-65',
        planned: '',
        estimatedGPS: '17:18',
        distanceGPS: '13.4 KM',
      };

      const arraivalTimeText = service.checkArraivalTime(arraival);

      expect(arraivalTimeText).toStrictEqual('Menos de 10 minutos');
    });

    it('should return Más de 10 minutos', () => {
      jest.setSystemTime(new Date('2024-11-25T17:00:37').getTime());
      const arraival = {
        carPlate: 'ABCA-65',
        planned: '',
        estimatedGPS: '17:18',
        distanceGPS: '13.4 KM',
      };

      const arraivalTimeText = service.checkArraivalTime(arraival);

      expect(arraivalTimeText).toStrictEqual('Más de 10 minutos');
    });
  });

  describe('getLineNumberFromDescription tests', () => {
    it('should return a list of numbers', () => {
      const numbers = service.getLineNumberFromDescription('10N');

      expect(numbers).toBe('10');
    });

    it('should throw an error if no numbers found', () => {
      expect(() => {
        service.getLineNumberFromDescription('N');
      }).toThrow('No numbers found');
    });
  });

  describe('getLineLetterFromDescription tests', () => {
    it('should return a list of letters', () => {
      const letters = service.getLineLetterFromDescription('10N');

      expect(letters).toBe('N');
    });

    it('should throw an error if no letters found', () => {
      expect(() => {
        service.getLineLetterFromDescription('10');
      }).toThrow('No letters found');
    });
  });

  describe('getLineDescription tests', () => {
    it('should return a line description', () => {
      const description = service.getLineDescription(
        '10K',
        'Vía Láctea 10K - Leonera',
      );

      expect(description).toBe('Vía Láctea - Leonera');
    });
  });
});
