import moment from 'moment';
import LineDetail from '../repositories/LineDetail';
import {getHours, getMinutes, getSeconds} from '../../utils/DateUtils';
import Arrival from '../repositories/Arrival';

// TODO: Change to a better name or split ?
class BusStopInfoService {
  private lines: LineDetail[];

  constructor(lines: LineDetail[]) {
    this.lines = lines;
  }

  getLines(): LineDetail[] {
    return this.lines;
  }

  getLinesByNumber(lineNumber: string): LineDetail {
    const line = this.lines.find(bus => bus.lineNumber === lineNumber);

    if (!line) {
      throw new Error('No buses found');
    }

    return line;
  }

  pruneBusList(start: number, howMany: number): LineDetail[] {
    const end = start + howMany;
    return this.lines.slice(start, end);
  }

  getNextArraival(lineNumber: string): Arrival {
    const currentTime = moment();

    const nextArraival = this.getLinesByNumber(lineNumber).arrivals.find(
      arrival => {
        const compareTime = moment();
        compareTime.set('hour', getHours(arrival.estimatedGPS));
        compareTime.set('minute', getMinutes(arrival.estimatedGPS));
        compareTime.set('second', getSeconds(arrival.estimatedGPS));

        if (compareTime.isAfter(currentTime)) {
          return arrival;
        }
      },
    );

    if (!nextArraival) {
      throw new Error('No next arrival');
    }

    return nextArraival;
  }

  checkArraivalTime(arrival: Arrival): string {
    const compareTime = moment();
    compareTime.set('hour', getHours(arrival.estimatedGPS));
    compareTime.set('minute', getMinutes(arrival.estimatedGPS));
    compareTime.set('second', getSeconds(arrival.estimatedGPS));

    const now = moment();
    const diffInMinutes = compareTime.diff(now, 'minutes');

    if (diffInMinutes <= 3) {
      return '< a 3 minutos';
    } else if (diffInMinutes > 3 && diffInMinutes < 6) {
      return 'Entre 3 a 5 minutos';
    } else if (diffInMinutes >= 6 && diffInMinutes <= 10) {
      return 'Menos de 10 minutos';
    } else {
      return 'Más de 10 minutos';
    }
  }

  getLineNumberFromDescription(description: string): string {
    const numbers = description.match(/\d+/g);

    if (!numbers) {
      throw new Error('No numbers found');
    }

    return numbers.join('');
  }

  getLineLetterFromDescription(description: string): string {
    const letters = description.match(/[a-zA-Z]+/g);

    if (!letters) {
      throw new Error('No letters found');
    }

    return letters.join('');
  }

  getLineDescription(description: string, line: string): string {
    const space = ' '; // this is to eliminate the extra space left when applying the replace.
    return line.replace(`${space}${description}`, '');
  }
}

export default BusStopInfoService;
