import axios from 'axios';
import MockAdapter from 'axios-mock-adapter';
import DevicesAPI from '../DevicesAPI';

const mockAdapter = new MockAdapter(axios);

const BASE_URL = 'https://test.cl';

const deviceAPI = new DevicesAPI(BASE_URL);

describe('devices tests', () => {
  it('should be defined', () => {
    expect(deviceAPI).toBeDefined();
  });

  describe('whoami', () => {
    it('should return stop information by device id', async () => {
      mockAdapter.onPost(`${BASE_URL}/api/dispositivos/whoami/`).reply(200, {
        stopNumber: 'stopNumber',
        stopName: 'stopName',
      });

      const response = await deviceAPI.whoami({
        token: 'token',
        deviceId: 'deviceId',
      });

      expect(response).toMatchObject({
        stopNumber: 'stopNumber',
        stopName: 'stopName',
      });
    });

    it('should throw an error if token is not provided', async () => {
      await expect(
        deviceAPI.whoami({token: '', deviceId: 'deviceId'}),
      ).rejects.toThrow('token is required');
    });

    it('should throw an error if deviceId is not provided', async () => {
      await expect(
        deviceAPI.whoami({token: 'token', deviceId: ''}),
      ).rejects.toThrow('deviceId is required');
    });

    it('should return an error if it fails to request stop information', async () => {
      mockAdapter.onPost(`${BASE_URL}/api/dispositivos/whoami/`).reply(400, {
        error: 'error',
      });

      await expect(
        deviceAPI.whoami({
          token: 'token',
          deviceId: 'deviceId',
        }),
      ).rejects.toThrow('Request failed with status code 400');
    });
  });

  describe('getInfoDevice', () => {
    it('should return stop information by device id', async () => {
      mockAdapter
        .onPost(`${BASE_URL}/api/dispositivos/getInfoDevice/`)
        .reply(200, {
          stopNumber: 'stopNumber',
          stopName: 'stopName',
        });

      const response = await deviceAPI.getInfoDevice({
        token: 'token',
        deviceId: 'deviceId',
      });

      expect(response).toMatchObject({
        stopNumber: 'stopNumber',
        stopName: 'stopName',
      });
    });

    it('should throw an error if token is not provided', async () => {
      await expect(
        deviceAPI.getInfoDevice({token: '', deviceId: 'deviceId'}),
      ).rejects.toThrow('token is required');
    });

    it('should throw an error if deviceId is not provided', async () => {
      await expect(
        deviceAPI.getInfoDevice({token: 'token', deviceId: ''}),
      ).rejects.toThrow('deviceId is required');
    });

    it('should return an error if it fails to request stop information', async () => {
      mockAdapter
        .onPost(`${BASE_URL}/api/dispositivos/getInfoDevice/`)
        .reply(400, {
          error: 'error',
        });

      await expect(
        deviceAPI.getInfoDevice({
          token: 'token',
          deviceId: 'deviceId',
        }),
      ).rejects.toThrow('Request failed with status code 400');
    });
  });
});
