import {useCallback, useEffect, useState} from 'react';
import remoteConfig from '@react-native-firebase/remote-config';
import Status from '../../utils/Status';

const useRemoteConfig = () => {
  const [status, setStatus] = useState(Status.LOADING);

  const getString = useCallback(
    (key: string) => remoteConfig().getString(key),
    [],
  );

  useEffect(() => {
    const init = async () => {
      try {
        await remoteConfig().setConfigSettings({
          minimumFetchIntervalMillis: 3600000,
        });

        // TODO: Add default values for remote config
        await remoteConfig().setDefaults({
          BASE_URL: '',
          HEADER_IMAGE_URL: '',
          USER: '',
          PASS: '',
          CHANGE_PAGE_INTERVAL: 0,
          UPDATE_BUSES_LIST_INTERVAL: 0,
        });

        const isActivated = await remoteConfig().fetchAndActivate();

        if (isActivated) {
          setStatus(Status.SUCCESS);
        }
      } catch (error) {
        setStatus(Status.ERROR);
      }
    };

    init();
  }, []);

  return {status, getString};
};

export default useRemoteConfig;
