import DevicesRepository from '../../domain/repositories/DevicesRepository';
import DevicesAPI from '../api/clients/DevicesAPI';
import DeviceInfoResponse from '../api/models/DeviceInfoResponse';
import toDeviceInfoResponse from './mappers/toDeviceInfoResponse';
import WhoAmIResponse from '../../domain/repositories/WhoAmIResponse';
import DeviceRequest from '../api/models/DeviceRequest';
import toWhoAmIResponse from './mappers/toWhoAmIResponse';

class DevicesRepositoryImpl implements DevicesRepository {
  private devicesAPI: DevicesAPI;

  constructor(devicesAPI: DevicesAPI) {
    this.devicesAPI = devicesAPI;
  }

  async whoAmI(request: DeviceRequest): Promise<WhoAmIResponse> {
    const response = await this.devicesAPI.whoami(request);

    return toWhoAmIResponse(response);
  }

  async getDeviceInfo(request: DeviceRequest): Promise<DeviceInfoResponse> {
    const response = await this.devicesAPI.getInfoDevice(request);

    return toDeviceInfoResponse(response);
  }
}

export default DevicesRepositoryImpl;
