import DevicesRepositoryImpl from '../DevicesRepositoryImpl';
import DevicesAPI from '../../api/clients/DevicesAPI';
import DeviceInfoResponse from '../../api/models/DeviceInfoResponse';
import LineDetail from '../../../domain/repositories/LineDetail';

jest.mock('../../api/clients/DevicesAPI');

describe('DevicesRepositoryImpl tests', () => {
  it('should be defined', () => {
    expect(DevicesRepositoryImpl).toBeDefined();
  });

  it('should return a whoami response', async () => {
    const mockedDevicesAPI = new DevicesAPI(
      'https://api.example.com',
    ) as jest.Mocked<DevicesAPI>;

    mockedDevicesAPI.whoami.mockResolvedValue({
      WhoamiResponse: {NombreParadero: 'stopName', NroParadero: 'stopNumber'},
    });

    const repo = new DevicesRepositoryImpl(mockedDevicesAPI);

    const whoami = await repo.whoAmI({
      token: 'token',
      deviceId: 'deviceId',
    });

    expect(whoami).toMatchObject({
      stopNumber: 'stopNumber',
      stopName: 'stopName',
    });
  });

  it('should return a device info response', async () => {
    const mockedDevicesAPI = new DevicesAPI(
      'https://api.example.com',
    ) as jest.Mocked<DevicesAPI>;

    mockedDevicesAPI.getInfoDevice.mockResolvedValue({
      GetInfoDeviceResponse: {
        MensajeParadero: 'stopMessage',
        DetalleLineas: [
          {
            colorFondo: 'colorFondo',
            colorLetra: 'colorLetra',
            Descripcion: 'Descripcion',
            Linea: 'Linea',
            Llegadas: [
              {
                DistanciaGPS: 'DistanciaGPS',
                EstimadaGPS: 'EstimadaGPS',
                Patente: 'Patente',
                Planificada: 'Planificada',
              },
            ],
            Mensajelinea: 'Mensajelinea',
            TipoLocomocion: 0,
          },
        ],
      },
    });

    const repo = new DevicesRepositoryImpl(mockedDevicesAPI);

    const deviceInfo = await repo.getDeviceInfo({
      token: 'token',
      deviceId: 'deviceId',
    });

    expect(deviceInfo).toMatchObject({
      lineDetails: [
        {
          arrivals: [
            {
              carPlate: 'Patente',
              distanceGPS: 'DistanciaGPS',
              estimatedGPS: 'EstimadaGPS',
              planned: 'Planificada',
            },
          ],
          backgroundColor: 'colorFondo',
          description: 'Descripcion',
          letterColor: 'colorLetra',
          lineMessage: 'Mensajelinea',
          lineNumber: 'Linea',
          locomotionType: 0,
        } as LineDetail,
      ],
      stopMessage: 'stopMessage',
    } as DeviceInfoResponse);
  });
});
