import {GetInfoDeviceResponse} from '../../../api/models/GetInfoDeviceResponse';
import toDeviceInfoResponse from '../toDeviceInfoResponse';

describe('toDeviceInfoResponse tests', () => {
  it('should be defined', () => {});

  it('should map to DeviceInfoResponse', () => {
    const responseFromBackEnd: GetInfoDeviceResponse = {
      GetInfoDeviceResponse: {
        DetalleLineas: [
          {
            Linea: '803010',
            Descripcion: 'Tucapel',
            TipoLocomocion: 1,
            colorFondo: 'Hexadecimal',
            colorLetra: 'Hexadecimal',
            Llegadas: [
              {
                Patente: 'RPDA-98',
                Planificada: '',
                EstimadaGPS: '15:08',
                DistanciaGPS: '1.0 KM',
              },
              {
                Patente: 'WYXYZ-22',
                Planificada: '',
                EstimadaGPS: '15:42',
                DistanciaGPS: '5.0 KM',
              },
              {
                Patente: 'ABCA-65',
                Planificada: '',
                EstimadaGPS: '16:18',
                DistanciaGPS: '13.4 KM',
              },
            ],
            Mensajelinea: '',
          },
          {
            Linea: '5487',
            Descripcion: 'Centauro',
            TipoLocomocion: 1,
            colorFondo: 'Hexadecimal',
            colorLetra: 'Hexadecimal',
            Llegadas: [
              {
                Patente: 'PLKJ-32',
                Planificada: '15:13',
                EstimadaGPS: '',
                DistanciaGPS: '',
              },
              {
                Patente: 'GHLK-11',
                Planificada: '15:39',
                EstimadaGPS: '',
                DistanciaGPS: '',
              },
              {
                Patente: 'DFQW-55',
                Planificada: '16:22',
                EstimadaGPS: '',
                DistanciaGPS: '',
              },
            ],
            Mensajelinea: 'Sin info. GPS, la informacion es estimada',
          },
        ],
        MensajeParadero: 'No considerar, uso futuro',
      },
    };

    const mappedResponse = toDeviceInfoResponse(responseFromBackEnd);

    expect(mappedResponse).toMatchObject({
      lineDetails: [
        {
          lineNumber: '803010',
          description: 'Tucapel',
          locomotionType: 1,
          backgroundColor: 'Hexadecimal',
          letterColor: 'Hexadecimal',
          lineMessage: '',
          arrivals: [
            {
              carPlate: 'RPDA-98',
              planned: '',
              estimatedGPS: '15:08',
              distanceGPS: '1.0 KM',
            },
            {
              carPlate: 'WYXYZ-22',
              planned: '',
              estimatedGPS: '15:42',
              distanceGPS: '5.0 KM',
            },
            {
              carPlate: 'ABCA-65',
              planned: '',
              estimatedGPS: '16:18',
              distanceGPS: '13.4 KM',
            },
          ],
        },
        {
          lineNumber: '5487',
          description: 'Centauro',
          locomotionType: 1,
          backgroundColor: 'Hexadecimal',
          letterColor: 'Hexadecimal',
          lineMessage: 'Sin info. GPS, la informacion es estimada',
          arrivals: [
            {
              carPlate: 'PLKJ-32',
              planned: '15:13',
              estimatedGPS: '',
              distanceGPS: '',
            },
            {
              carPlate: 'GHLK-11',
              planned: '15:39',
              estimatedGPS: '',
              distanceGPS: '',
            },
            {
              carPlate: 'DFQW-55',
              planned: '16:22',
              estimatedGPS: '',
              distanceGPS: '',
            },
          ],
        },
      ],
      stopMessage: 'No considerar, uso futuro',
    });
  });
});
