import Arrival from '../../../domain/repositories/Arrival';
import LineDetail from '../../../domain/repositories/LineDetail';
import DeviceInfoResponse from '../../api/models/DeviceInfoResponse';
import {GetInfoDeviceResponse} from '../../api/models/GetInfoDeviceResponse';

const toDeviceInfoResponse = (
  response: GetInfoDeviceResponse,
): DeviceInfoResponse => {
  const {
    GetInfoDeviceResponse: {DetalleLineas, MensajeParadero},
  } = response;

  const mappedLines: LineDetail[] = DetalleLineas.map(linea => {
    const {
      Linea,
      Descripcion,
      TipoLocomocion,
      colorFondo,
      colorLetra,
      Mensajelinea,
      Llegadas,
    } = linea;

    const mappedArrivals: Arrival[] = Llegadas.map(llegada => {
      const {Patente, Planificada, EstimadaGPS, DistanciaGPS} = llegada;

      return {
        carPlate: Patente,
        planned: Planificada,
        estimatedGPS: EstimadaGPS,
        distanceGPS: DistanciaGPS,
      };
    });

    return {
      lineNumber: Linea,
      description: Descripcion,
      locomotionType: TipoLocomocion,
      backgroundColor: colorFondo,
      letterColor: colorLetra,
      lineMessage: Mensajelinea,
      arrivals: mappedArrivals,
    };
  });

  return {
    lineDetails: mappedLines,
    stopMessage: MensajeParadero,
  };
};

export default toDeviceInfoResponse;
