import {View, Text, StyleSheet} from 'react-native';

export interface Line {
  lineNumber: string;
  lineLetter: string;
  letterColor: string;
  backgroundColor: string;
  estimatedArrivalTimeInMinutes: string;
  lineDescription: string;
}

export interface TableProps {
  data: Line[];
}

const Table = ({data}: TableProps) => {
  const rows = 7;
  const columns = 3;

  const baseTableData: Line[][] = Array.from({length: rows}, () =>
    new Array(columns).fill({
      lineNumber: '',
      lineLetter: '',
      letterColor: '',
      backgroundColor: '',
      estimatedArrivalTimeInMinutes: '',
    }),
  );

  data.map((item, index) => {
    const row = Math.floor(index / columns);
    const column = index % columns;
    baseTableData[row][column] = item;
  });

  return (
    <View style={tableStyles.table}>
      {baseTableData.map((row, rowIndex) => (
        <View key={rowIndex} style={tableStyles.row}>
          {row.map((cell, cellIndex) => {
            if (cell.lineNumber === '') {
              return <View style={tableStyles.cell} key={cellIndex} />;
            }

            const [first, second] = cell.lineDescription.split('-');

            return (
              <View style={[tableStyles.cell]} key={cellIndex}>
                <View style={tableStyles.lineInformationContainer}>
                  <Text style={tableStyles.lineNumber}>{cell.lineNumber}</Text>
                  <View
                    style={[
                      tableStyles.letterContainer,
                      {backgroundColor: `#${cell.backgroundColor}` || 'grey'},
                    ]}>
                    <Text style={tableStyles.lineLetter}>
                      {cell.lineLetter}
                    </Text>
                  </View>
                </View>
                <View
                  style={[
                    tableStyles.timeContainer,
                    {backgroundColor: `#${cell.backgroundColor}` || 'grey'},
                  ]}>
                  <Text style={tableStyles.time} numberOfLines={1}>
                    {first}
                  </Text>
                  <Text style={tableStyles.time} numberOfLines={1}>
                    {second}
                  </Text>
                  <Text style={tableStyles.time}>
                    {cell.estimatedArrivalTimeInMinutes}
                  </Text>
                </View>
              </View>
            );
          })}
        </View>
      ))}
    </View>
  );
};

const tableStyles = StyleSheet.create({
  table: {
    flex: 1,
    backgroundColor: 'white',
  },
  row: {
    flex: 1,
    flexDirection: 'row',
  },
  cell: {
    flex: 1,
    borderWidth: 1,
    flexDirection: 'column',
    borderColor: 'grey',
  },
  lineInformationContainer: {
    flex: 1,
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
  },
  timeContainer: {
    alignItems: 'center',
    backgroundColor: 'blue',
  },
  lineNumber: {
    fontSize: 20,
    marginRight: 8,
    fontWeight: 'bold',
    color: 'grey',
  },
  lineLetter: {
    fontSize: 14,
    color: 'white',
    fontWeight: 'bold',
  },
  letterContainer: {
    paddingHorizontal: 16,
    paddingVertical: 8,
    borderRadius: 50,
  },
  time: {
    fontSize: 12,
    fontWeight: 'bold',
    color: 'white',
  },
  lineDescription: {
    fontSize: 12,
    fontWeight: 'bold',
    color: 'white',
  },
});

export default Table;
