import {ActivityIndicator, StyleSheet, View} from 'react-native';
import Container from '../components/Container';
import Header from '../components/Header';
import useDevices from '../../infraestructure/hooks/useDevices';
import Banner from '../components/Banner';
import RemoteConfigKeys from '../../utils/RemoteConfigKeys';
import BusList from '../components/BusList';
import useRemoteConfig from '../../infraestructure/hooks/useRemoteConfig';
import Status from '../../utils/Status';

const BANNER_TEXT = 'Buses que se detienen en esta parada';

const BusStopInfoScreen = () => {
  const {status, displayedLines, stopName} = useDevices().state;
  const {status: remoteConfigStatus, getString} = useRemoteConfig();

  const image = getString(RemoteConfigKeys.HEADER_IMAGE_URL);
  const [first, second] = stopName.split('-');
  const title = first ? first.trim() : '';
  const subTitle = second ? second.trim() : '';

  if (remoteConfigStatus === Status.LOADING) {
    return (
      <Container style={styles.container}>
        <ActivityIndicator />
      </Container>
    );
  }

  return (
    <Container style={styles.container}>
      <Header
        style={styles.headerContainer}
        subTitle={subTitle}
        title={title}
        image={image}
      />
      <Banner style={styles.bannerContainer} text={BANNER_TEXT} />
      <BusList
        buses={displayedLines}
        style={styles.bodyContainer}
        status={status}
      />
      <View style={styles.footerContainer}>
        {/* {TODO implement footer} */}
      </View>
    </Container>
  );
};

const styles = StyleSheet.create({
  container: {
    justifyContent: 'center',
  },
  headerContainer: {
    flex: 1.5,
    backgroundColor: 'orange',
  },
  bannerContainer: {
    flex: 0.5,
    backgroundColor: 'grey',
  },
  bodyContainer: {
    flex: 10,
    justifyContent: 'center',
  },
  footerContainer: {
    flex: 1,
    backgroundColor: 'grey',
  },
});

export default BusStopInfoScreen;
